@@ -83,6 +83,19 @@ class TSquareAPI(object):
         del user_data['password'] # tsquare doesn't store passwords
         return TSquareUser(**user_data)
 
+    @requires_authentication
+    def get_site_by_id(self, id):
+        """
+        Looks up a site by ID and returns a TSquareSite representing that
+        object, or throws an exception if no such site is found.
+        @param id - The entityID of the site to look up
+        @returns A TSquareSite object
+        """
+        response = self._session.get(BASE_URL_TSQUARE + '/site/{}.json'.format(id))
+        response.raise_for_status()
+        site_data = response.json()
+        return TSquareSite(**site_data)
+        
     @requires_authentication
     def get_sites(self, filter_func=lambda x: True):
         """
